// RXTX_BITSLICE: RXTX_BITSLICE for bidirectional I/O using Native Mode
//                UltraScale
// Xilinx HDL Language Template, version 2024.2

RXTX_BITSLICE #(
   .ENABLE_PRE_EMPHASIS("FALSE"), // Enable the pre-emphasis
   .FIFO_SYNC_MODE("FALSE"),      // Always set to FALSE. TRUE is reserved for later use.
   .INIT(1'b1),                   // Defines initial O value
   .IS_RX_CLK_INVERTED(1'b0),     // Optional inversion for RX_CLK
   .IS_RX_RST_DLY_INVERTED(1'b0), // Optional inversion for RX_RST_DLY
   .IS_RX_RST_INVERTED(1'b0),     // Optional inversion for RX_RST
   .IS_TX_CLK_INVERTED(1'b0),     // Optional inversion for TX_CLK
   .IS_TX_RST_DLY_INVERTED(1'b0), // Optional inversion for TX_RST_DLY
   .IS_TX_RST_INVERTED(1'b0),     // Optional inversion for TX_RST
   .RX_DATA_TYPE("DATA"),         // Defines what the RX input pin is carrying (CLOCK, DATA, DATA_AND_CLOCK,
                                  // SERIAL)
   .RX_DATA_WIDTH(8),             // Defines the width of the serial-to-parallel converter (4-8)
   .RX_DELAY_FORMAT("TIME"),      // Units of the RX DELAY_VALUE (COUNT, TIME)
   .RX_DELAY_TYPE("FIXED"),       // Set the type of RX tap delay line (FIXED, VARIABLE, VAR_LOAD)
   .RX_DELAY_VALUE(0),            // RX Input delay value setting in ps
   .RX_REFCLK_FREQUENCY(300.0),   // Specification of the RX reference clock frequency in MHz (200.0-2667.0)
   .RX_UPDATE_MODE("ASYNC"),      // Determines when updates to the RX delay will take effect (ASYNC,
                                  // MANUAL, SYNC)
   .SIM_DEVICE("ULTRASCALE"),     // Set the device version for simulation functionality (ULTRASCALE)
   .TBYTE_CTL("TBYTE_IN"),        // Select between T and TBYTE_IN inputs
   .TX_DATA_WIDTH(8),             // Parallel data input width (4-8)
   .TX_DELAY_FORMAT("TIME"),      // Units of the TX DELAY_VALUE (COUNT, TIME)
   .TX_DELAY_TYPE("FIXED"),       // Set the type of TX tap delay line (FIXED, VARIABLE, VAR_LOAD)
   .TX_DELAY_VALUE(0),            // TX Input delay value setting in ps
   .TX_OUTPUT_PHASE_90("FALSE"),  // Delays the output phase by 90-degrees
   .TX_REFCLK_FREQUENCY(300.0),   // Specification of the TX reference clock frequency in MHz (200.0-2667.0)
   .TX_UPDATE_MODE("ASYNC")       // Determines when updates to the delay will take effect (ASYNC, MANUAL,
                                  // SYNC)
)
RXTX_BITSLICE_inst (
   .FIFO_EMPTY(FIFO_EMPTY),           // 1-bit output: FIFO empty flag
   .FIFO_WRCLK_OUT(FIFO_WRCLK_OUT),   // 1-bit output: FIFO source synchronous write clock out to the device
                                      // logic (currently unsupported, do not connect)

   .O(O),                             // 1-bit output: Serialized output going to output buffer
   .Q(Q),                             // 8-bit output: Registered output data from FIFO
   .RX_BIT_CTRL_OUT(RX_BIT_CTRL_OUT), // 40-bit output: RX Output bus to BITSLICE_CONTROL
   .RX_CNTVALUEOUT(RX_CNTVALUEOUT),   // 9-bit output: RX Counter value from device logic
   .TX_BIT_CTRL_OUT(TX_BIT_CTRL_OUT), // 40-bit output: Output bus to BITSLICE_CONTROL for TX
   .TX_CNTVALUEOUT(TX_CNTVALUEOUT),   // 9-bit output: TX Counter value to device logic
   .T_OUT(T_OUT),                     // 1-bit output: Byte group 3-state output
   .D(D),                             // 8-bit input: Data from device logic
   .DATAIN(DATAIN),                   // 1-bit input: Input signal from IOBUF
   .FIFO_RD_CLK(FIFO_RD_CLK),         // 1-bit input: FIFO read clock
   .FIFO_RD_EN(FIFO_RD_EN),           // 1-bit input: FIFO read enable
   .RX_BIT_CTRL_IN(RX_BIT_CTRL_IN),   // 40-bit input: RX Input bus from BITSLICE_CONTROL
   .RX_CE(RX_CE),                     // 1-bit input: Clock enable for IDELAY
   .RX_CLK(RX_CLK),                   // 1-bit input: RX Clock used to sample LOAD, CE, INC
   .RX_CNTVALUEIN(RX_CNTVALUEIN),     // 9-bit input: RX Counter value from device logic
   .RX_EN_VTC(RX_EN_VTC),             // 1-bit input: RX Enable to keep stable delay over VT
   .RX_INC(RX_INC),                   // 1-bit input: RX Increment the current delay tap setting
   .RX_LOAD(RX_LOAD),                 // 1-bit input: RX Load the CNTVALUEIN tap setting
   .RX_RST(RX_RST),                   // 1-bit input: RX Asynchronous assert, synchronous deassert for
                                      // RXTX_BITSLICE ISERDES

   .RX_RST_DLY(RX_RST_DLY),           // 1-bit input: RX Reset the internal DELAY value to DELAY_VALUE
   .T(T),                             // 1-bit input: Legacy T byte input from device logic
   .TBYTE_IN(TBYTE_IN),               // 1-bit input: Byte group 3-state input from TX_BITSLICE_TRI
   .TX_BIT_CTRL_IN(TX_BIT_CTRL_IN),   // 40-bit input: TX Input bus from BITSLICE_CONTROL
   .TX_CE(TX_CE),                     // 1-bit input: Clock enable for ODELAY
   .TX_CLK(TX_CLK),                   // 1-bit input: TX Clock used to sample LOAD, CE, INC
   .TX_CNTVALUEIN(TX_CNTVALUEIN),     // 9-bit input: TX Counter value from device logic
   .TX_EN_VTC(TX_EN_VTC),             // 1-bit input: TX Enable to keep stable delay over VT
   .TX_INC(TX_INC),                   // 1-bit input: TX Increment the current delay tap setting
   .TX_LOAD(TX_LOAD),                 // 1-bit input: TX Load the CNTVALUEIN tap setting
   .TX_RST(TX_RST),                   // 1-bit input: TX Asynchronous assert, synchronous deassert for
                                      // RXTX_BITSLICE OSERDES

   .TX_RST_DLY(TX_RST_DLY)            // 1-bit input: TX Reset the internal DELAY value to DELAY_VALUE
);

// End of RXTX_BITSLICE_inst instantiation
