-- BITSLICE_CONTROL: BITSLICE_CONTROL for control using Native Mode
--                   UltraScale
-- Xilinx HDL Language Template, version 2024.2

BITSLICE_CONTROL_inst : BITSLICE_CONTROL
generic map (
   DIV_MODE => "DIV2",               -- Controller DIV2/DIV4 mode (DIV2, DIV4)
   EN_CLK_TO_EXT_NORTH => "DISABLE", -- Enable clock forwarding to north
   EN_CLK_TO_EXT_SOUTH => "DISABLE", -- Enable clock forwarding to south
   EN_DYN_ODLY_MODE => "FALSE",      -- Enable dynamic output delay mode
   EN_OTHER_NCLK => "FALSE",         -- Select the NCLK from the other BITSLICE_CONTROL in the nibble
                                     -- (FALSE, TRUE).
   EN_OTHER_PCLK => "FALSE",         -- Select the PCLK from the other BITSLICE_CONTROL in the nibble
                                     -- (FALSE, TRUE).
   IDLY_VT_TRACK => "TRUE",          -- Enable VT tracking for input delays
   INV_RXCLK => "FALSE",             -- Invert clock path from IOB to upper RX bitslice
   ODLY_VT_TRACK => "TRUE",          -- Enable VT tracking for output delays
   QDLY_VT_TRACK => "TRUE",          -- Enable VT tracking for clock delays
   READ_IDLE_COUNT => X"00",         -- Gap count between read bursts for ODT control counter (0-3f)
   REFCLK_SRC => "PLLCLK",           -- Select the input clock for delay control (PLLCLK, REFCLK). REFCLK is
                                     -- only supported for RX_BITSLICE.
   ROUNDING_FACTOR => 16,            -- Rounding factor in BISC spec (128-8)
   RXGATE_EXTEND => "FALSE",         -- Reserved for use by Memory IP. Do Not Change.
   RX_CLK_PHASE_N => "SHIFT_0",      -- Shift the Read CLK relative to read DQ during calibration (SHIFT_0,
                                     -- SHIFT_90)
   RX_CLK_PHASE_P => "SHIFT_0",      -- Shift the Read CLK relative to read DQ during calibration (SHIFT_0,
                                     -- SHIFT_90)
   RX_GATING => "DISABLE",           -- ENABLE/DISABLE read DQS gating
   SELF_CALIBRATE => "ENABLE",       -- Enable BISC of nibble controlled by BITSLICE_CONTROL
   SERIAL_MODE => "FALSE",           -- Put BITSLICE read paths into serial mode (FALSE, TRUE)
   SIM_DEVICE => "ULTRASCALE_PLUS",  -- Set the device version for simulation functionality (ULTRASCALE,
                                     -- ULTRASCALE_PLUS, ULTRASCALE_PLUS_ES1, ULTRASCALE_PLUS_ES2)
   TX_GATING => "DISABLE"            -- ENABLE/DISABLE clock gating in WClkgen
)
port map (
   CLK_TO_EXT_NORTH => CLK_TO_EXT_NORTH,       -- 1-bit output: Inter-byte clock going to north
                                               -- BITSLICE_CONTROL

   CLK_TO_EXT_SOUTH => CLK_TO_EXT_SOUTH,       -- 1-bit output: Inter-byte clock going to south
                                               -- BITSLICE_CONTROL

   DLY_RDY => DLY_RDY,                         -- 1-bit output: Fixed delay calibration complete
   DYN_DCI => DYN_DCI,                         -- 7-bit output: Direct control of IOB DCI when using a
                                               -- memory interface

   NCLK_NIBBLE_OUT => NCLK_NIBBLE_OUT,         -- 1-bit output: Intra-byte DQS strobes/clock to other
                                               -- control block

   PCLK_NIBBLE_OUT => PCLK_NIBBLE_OUT,         -- 1-bit output: Intra-byte DQS strobes/clock to other
                                               -- control block

   RIU_RD_DATA => RIU_RD_DATA,                 -- 16-bit output: RIU Output Read data to the controller
   RIU_VALID => RIU_VALID,                     -- 1-bit output: Last data written has been accepted when High
   RX_BIT_CTRL_OUT0 => RX_BIT_CTRL_OUT0,       -- 40-bit output: Output bus to Bitslice 0
   RX_BIT_CTRL_OUT1 => RX_BIT_CTRL_OUT1,       -- 40-bit output: Output bus to Bitslice 1
   RX_BIT_CTRL_OUT2 => RX_BIT_CTRL_OUT2,       -- 40-bit output: Output bus to Bitslice 2
   RX_BIT_CTRL_OUT3 => RX_BIT_CTRL_OUT3,       -- 40-bit output: Output bus to Bitslice 3
   RX_BIT_CTRL_OUT4 => RX_BIT_CTRL_OUT4,       -- 40-bit output: Output bus to Bitslice 4
   RX_BIT_CTRL_OUT5 => RX_BIT_CTRL_OUT5,       -- 40-bit output: Output bus to Bitslice 5
   RX_BIT_CTRL_OUT6 => RX_BIT_CTRL_OUT6,       -- 40-bit output: Output bus to Bitslice 6
   TX_BIT_CTRL_OUT0 => TX_BIT_CTRL_OUT0,       -- 40-bit output: Output bus to Bitslice 0
   TX_BIT_CTRL_OUT1 => TX_BIT_CTRL_OUT1,       -- 40-bit output: Output bus to Bitslice 1
   TX_BIT_CTRL_OUT2 => TX_BIT_CTRL_OUT2,       -- 40-bit output: Output bus to Bitslice 2
   TX_BIT_CTRL_OUT3 => TX_BIT_CTRL_OUT3,       -- 40-bit output: Output bus to Bitslice 3
   TX_BIT_CTRL_OUT4 => TX_BIT_CTRL_OUT4,       -- 40-bit output: Output bus to Bitslice 4
   TX_BIT_CTRL_OUT5 => TX_BIT_CTRL_OUT5,       -- 40-bit output: Output bus to Bitslice 5
   TX_BIT_CTRL_OUT6 => TX_BIT_CTRL_OUT6,       -- 40-bit output: Output bus to Bitslice 6
   TX_BIT_CTRL_OUT_TRI => TX_BIT_CTRL_OUT_TRI, -- 40-bit output: Output bus to 3-state TX_BITSLICE_TRI
   VTC_RDY => VTC_RDY,                         -- 1-bit output: PHY calibration is complete
   CLK_FROM_EXT => CLK_FROM_EXT,               -- 1-bit input: Inter-byte clock coming from north or south
                                               -- BITSLICE_CONTROL

   EN_VTC => EN_VTC,                           -- 1-bit input: Enables voltage and temperature compensation
                                               -- when High

   NCLK_NIBBLE_IN => NCLK_NIBBLE_IN,           -- 1-bit input: Intra-byte DQS strobes from other/clock
                                               -- control block

   PCLK_NIBBLE_IN => PCLK_NIBBLE_IN,           -- 1-bit input: Intra-byte DQS strobes/clock from other
                                               -- control block

   PHY_RDCS0 => PHY_RDCS0,                     -- 4-bit input: Rank select
   PHY_RDCS1 => PHY_RDCS1,                     -- 4-bit input: Rank select
   PHY_RDEN => PHY_RDEN,                       -- 4-bit input: Read burst enable when using a memory
                                               -- interface

   PHY_WRCS0 => PHY_WRCS0,                     -- 4-bit input: Rank select
   PHY_WRCS1 => PHY_WRCS1,                     -- 4-bit input: Rank select
   PLL_CLK => PLL_CLK,                         -- 1-bit input: PLL clock input
   REFCLK => REFCLK,                           -- 1-bit input: Frequency reference clock for delay control
   RIU_ADDR => RIU_ADDR,                       -- 6-bit input: Address input for RIU
   RIU_CLK => RIU_CLK,                         -- 1-bit input: System clock from fabric for RIU access
   RIU_NIBBLE_SEL => RIU_NIBBLE_SEL,           -- 1-bit input: Nibble select to enable RIU read/write
   RIU_WR_DATA => RIU_WR_DATA,                 -- 16-bit input: RIU Input Write data from the controller
   RIU_WR_EN => RIU_WR_EN,                     -- 1-bit input: Enables write to RIU when High
   RST => RST,                                 -- 1-bit input: Asynchronous global reset
   RX_BIT_CTRL_IN0 => RX_BIT_CTRL_IN0,         -- 40-bit input: Input bus from Bitslice 0
   RX_BIT_CTRL_IN1 => RX_BIT_CTRL_IN1,         -- 40-bit input: Input bus from Bitslice 1
   RX_BIT_CTRL_IN2 => RX_BIT_CTRL_IN2,         -- 40-bit input: Input bus from Bitslice 2
   RX_BIT_CTRL_IN3 => RX_BIT_CTRL_IN3,         -- 40-bit input: Input bus from Bitslice 3
   RX_BIT_CTRL_IN4 => RX_BIT_CTRL_IN4,         -- 40-bit input: Input bus from Bitslice 4
   RX_BIT_CTRL_IN5 => RX_BIT_CTRL_IN5,         -- 40-bit input: Input bus from Bitslice 5
   RX_BIT_CTRL_IN6 => RX_BIT_CTRL_IN6,         -- 40-bit input: Input bus from Bitslice 6
   TBYTE_IN => TBYTE_IN,                       -- 4-bit input: Output enable for 3-state control
   TX_BIT_CTRL_IN0 => TX_BIT_CTRL_IN0,         -- 40-bit input: Input bus from Bitslice 0
   TX_BIT_CTRL_IN1 => TX_BIT_CTRL_IN1,         -- 40-bit input: Input bus from Bitslice 1
   TX_BIT_CTRL_IN2 => TX_BIT_CTRL_IN2,         -- 40-bit input: Input bus from Bitslice 2
   TX_BIT_CTRL_IN3 => TX_BIT_CTRL_IN3,         -- 40-bit input: Input bus from Bitslice 3
   TX_BIT_CTRL_IN4 => TX_BIT_CTRL_IN4,         -- 40-bit input: Input bus from Bitslice 4
   TX_BIT_CTRL_IN5 => TX_BIT_CTRL_IN5,         -- 40-bit input: Input bus from Bitslice 5
   TX_BIT_CTRL_IN6 => TX_BIT_CTRL_IN6,         -- 40-bit input: Input bus from Bitslice 6
   TX_BIT_CTRL_IN_TRI => TX_BIT_CTRL_IN_TRI    -- 40-bit input: Input bus from 3-state TX_BITSLICE_TRI
);

-- End of BITSLICE_CONTROL_inst instantiation
