-- FIFO18E2: 18Kb FIFO (First-In-First-Out) Block RAM Memory
--           UltraScale
-- Xilinx HDL Language Template, version 2024.2

FIFO18E2_inst : FIFO18E2
generic map (
   CASCADE_ORDER => "NONE",            -- FIRST, LAST, MIDDLE, NONE, PARALLEL
   CLOCK_DOMAINS => "INDEPENDENT",     -- COMMON, INDEPENDENT
   FIRST_WORD_FALL_THROUGH => "FALSE", -- FALSE, TRUE
   INIT => X"000000000",               -- Initial values on output port
   PROG_EMPTY_THRESH => 256,           -- Programmable Empty Threshold
   PROG_FULL_THRESH => 256,            -- Programmable Full Threshold
   -- Programmable Inversion Attributes: Specifies the use of the built-in programmable inversion
   IS_RDCLK_INVERTED => '0',           -- Optional inversion for RDCLK
   IS_RDEN_INVERTED => '0',            -- Optional inversion for RDEN
   IS_RSTREG_INVERTED => '0',          -- Optional inversion for RSTREG
   IS_RST_INVERTED => '0',             -- Optional inversion for RST
   IS_WRCLK_INVERTED => '0',           -- Optional inversion for WRCLK
   IS_WREN_INVERTED => '0',            -- Optional inversion for WREN
   RDCOUNT_TYPE => "RAW_PNTR",         -- EXTENDED_DATACOUNT, RAW_PNTR, SIMPLE_DATACOUNT, SYNC_PNTR
   READ_WIDTH => 4,                    -- 18-9
   REGISTER_MODE => "UNREGISTERED",    -- DO_PIPELINED, REGISTERED, UNREGISTERED
   RSTREG_PRIORITY => "RSTREG",        -- REGCE, RSTREG
   SLEEP_ASYNC => "FALSE",             -- FALSE, TRUE
   SRVAL => X"000000000",              -- SET/reset value of the FIFO outputs
   WRCOUNT_TYPE => "RAW_PNTR",         -- EXTENDED_DATACOUNT, RAW_PNTR, SIMPLE_DATACOUNT, SYNC_PNTR
   WRITE_WIDTH => 4                    -- 18-9
)
port map (
   -- Cascade Signals outputs: Multi-FIFO cascade signals
   CASDOUT => CASDOUT,             -- 32-bit output: Data cascade output bus
   CASDOUTP => CASDOUTP,           -- 4-bit output: Parity data cascade output bus
   CASNXTEMPTY => CASNXTEMPTY,     -- 1-bit output: Cascade next empty
   CASPRVRDEN => CASPRVRDEN,       -- 1-bit output: Cascade previous read enable
   -- Read Data outputs: Read output data
   DOUT => DOUT,                   -- 32-bit output: FIFO data output bus
   DOUTP => DOUTP,                 -- 4-bit output: FIFO parity output bus.
   -- Status outputs: Flags and other FIFO status outputs
   EMPTY => EMPTY,                 -- 1-bit output: Empty
   FULL => FULL,                   -- 1-bit output: Full
   PROGEMPTY => PROGEMPTY,         -- 1-bit output: Programmable empty
   PROGFULL => PROGFULL,           -- 1-bit output: Programmable full
   RDCOUNT => RDCOUNT,             -- 13-bit output: Read count
   RDERR => RDERR,                 -- 1-bit output: Read error
   RDRSTBUSY => RDRSTBUSY,         -- 1-bit output: Reset busy (sync to RDCLK)
   WRCOUNT => WRCOUNT,             -- 13-bit output: Write count
   WRERR => WRERR,                 -- 1-bit output: Write Error
   WRRSTBUSY => WRRSTBUSY,         -- 1-bit output: Reset busy (sync to WRCLK)
   -- Cascade Signals inputs: Multi-FIFO cascade signals
   CASDIN => CASDIN,               -- 32-bit input: Data cascade input bus
   CASDINP => CASDINP,             -- 4-bit input: Parity data cascade input bus
   CASDOMUX => CASDOMUX,           -- 1-bit input: Cascade MUX select
   CASDOMUXEN => CASDOMUXEN,       -- 1-bit input: Enable for cascade MUX select
   CASNXTRDEN => CASNXTRDEN,       -- 1-bit input: Cascade next read enable
   CASOREGIMUX => CASOREGIMUX,     -- 1-bit input: Cascade output MUX select
   CASOREGIMUXEN => CASOREGIMUXEN, -- 1-bit input: Cascade output MUX select enable
   CASPRVEMPTY => CASPRVEMPTY,     -- 1-bit input: Cascade previous empty
   -- Read Control Signals inputs: Read clock, enable and reset input signals
   RDCLK => RDCLK,                 -- 1-bit input: Read clock
   RDEN => RDEN,                   -- 1-bit input: Read enable
   REGCE => REGCE,                 -- 1-bit input: Output register clock enable
   RSTREG => RSTREG,               -- 1-bit input: Output register reset
   SLEEP => SLEEP,                 -- 1-bit input: Sleep Mode
   -- Write Control Signals inputs: Write clock and enable input signals
   RST => RST,                     -- 1-bit input: Reset
   WRCLK => WRCLK,                 -- 1-bit input: Write clock
   WREN => WREN,                   -- 1-bit input: Write enable
   -- Write Data inputs: Write input data
   DIN => DIN,                     -- 32-bit input: FIFO data input bus
   DINP => DINP                    -- 4-bit input: FIFO parity input bus
);

-- End of FIFO18E2_inst instantiation
